==> jc-1.4.0.tar.gz: gnu/javax/rmi/CORBA/DelegateFactory.h <==
// public class gnu.javax.rmi.CORBA.DelegateFactory

// class file dependencies
// @dep_class 145c981febce5f28 gnu_javax_rmi_CORBA_DelegateFactory
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_javax_rmi_CORBA_DelegateFactory_H_
#define _JC_gnu_javax_rmi_CORBA_DelegateFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$refs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$refs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$object	_jc_gnu_javax_rmi_CORBA_DelegateFactory$object;

typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct	_jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct;
typedef const struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods;
typedef const struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable;
typedef const struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype;

// Class fields structure
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct {
	struct _jc_java_util_HashMap$object	*cache;
};
extern _jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$class_fields;

// Constructors
extern void _jc_gnu_javax_rmi_CORBA_DelegateFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$object *);

// Static methods
extern void _jc_gnu_javax_rmi_CORBA_DelegateFactory$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Object$object *_jc_gnu_javax_rmi_CORBA_DelegateFactory$method$getInstance$a85610fc2893ba5b(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods {
};

// Vtable
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods	gnu_javax_rmi_CORBA_DelegateFactory;
};

// Vtype
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$refs {
    _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs	gnu_javax_rmi_CORBA_DelegateFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs	gnu_javax_rmi_CORBA_DelegateFactory;
};

// Object instance structure
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$object {
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype	*vtype;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype _jc_gnu_javax_rmi_CORBA_DelegateFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_CORBA_DelegateFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_CORBA_DelegateFactory$class_object;

#endif	/* _JC_gnu_javax_rmi_CORBA_DelegateFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/javax/rmi/CORBA/DelegateFactory.h <==
// public class gnu.javax.rmi.CORBA.DelegateFactory

// class file dependencies
// @dep_class 145c981febce5f28 gnu_javax_rmi_CORBA_DelegateFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_javax_rmi_CORBA_DelegateFactory_H_
#define _JC_gnu_javax_rmi_CORBA_DelegateFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$refs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$refs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs	_jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$object	_jc_gnu_javax_rmi_CORBA_DelegateFactory$object;

typedef struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct	_jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct;
typedef const struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods;
typedef const struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable;
typedef const struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype;

// Class fields structure
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct {
	struct _jc_java_util_HashMap$object	*cache;
};
extern _jc_gnu_javax_rmi_CORBA_DelegateFactory$fields_struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$class_fields;

// Constructors
extern void _jc_gnu_javax_rmi_CORBA_DelegateFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_javax_rmi_CORBA_DelegateFactory$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_javax_rmi_CORBA_DelegateFactory$method$getInstance$a85610fc2893ba5b(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods {
};

// Vtable
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vmethods	gnu_javax_rmi_CORBA_DelegateFactory;
};

// Vtype
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$refs {
    _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_refs	gnu_javax_rmi_CORBA_DelegateFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_javax_rmi_CORBA_DelegateFactory$sub_nonrefs	gnu_javax_rmi_CORBA_DelegateFactory;
};

// Object instance structure
struct _jc_gnu_javax_rmi_CORBA_DelegateFactory$object {
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype	*vtype;
	_jc_gnu_javax_rmi_CORBA_DelegateFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_CORBA_DelegateFactory$vtype _jc_gnu_javax_rmi_CORBA_DelegateFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_CORBA_DelegateFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_CORBA_DelegateFactory$class_object;

#endif	/* _JC_gnu_javax_rmi_CORBA_DelegateFactory_H_ */
